# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-30 13:21
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('entity_event', '0002_medium_creation_time'),
    ]

    operations = [
        migrations.AlterField(
            model_name='event',
            name='uuid',
            field=models.CharField(max_length=512, unique=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.11 on 2017-05-24 18:07
from __future__ import unicode_literals

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('entity_event', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='medium',
            name='time_created',
            field=models.DateTimeField(auto_now_add=True, default=datetime.datetime(2017, 5, 24, 18, 7, 45, 987701)),
            preserve_default=False,
        ),
    ]



# Generated by Django 2.2.8 on 2020-04-09 16:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('entity_event', '0004_auto_20180403_1655'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contextrenderer',
            name='name',
            field=models.CharField(max_length=256, unique=True),
        ),
        migrations.AlterField(
            model_name='medium',
            name='display_name',
            field=models.CharField(max_length=256),
        ),
        migrations.AlterField(
            model_name='medium',
            name='name',
            field=models.CharField(max_length=256, unique=True),
        ),
        migrations.AlterField(
            model_name='renderingstyle',
            name='display_name',
            field=models.CharField(default='', max_length=256),
        ),
        migrations.AlterField(
            model_name='renderingstyle',
            name='name',
            field=models.CharField(max_length=256, unique=True),
        ),
        migrations.AlterField(
            model_name='source',
            name='display_name',
            field=models.CharField(max_length=256),
        ),
        migrations.AlterField(
            model_name='source',
            name='name',
            field=models.CharField(max_length=256, unique=True),
        ),
        migrations.AlterField(
            model_name='sourcegroup',
            name='display_name',
            field=models.CharField(max_length=256),
        ),
        migrations.AlterField(
            model_name='sourcegroup',
            name='name',
            field=models.CharField(max_length=256, unique=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.11 on 2018-04-03 16:55
from __future__ import unicode_literals

import django.contrib.postgres.fields.jsonb
import django.core.serializers.json
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('entity_event', '0003_auto_20170830_1321'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contextrenderer',
            name='context_hints',
            field=django.contrib.postgres.fields.jsonb.JSONField(default=None, encoder=django.core.serializers.json.DjangoJSONEncoder, null=True),
        ),
        migrations.AlterField(
            model_name='event',
            name='context',
            field=django.contrib.postgres.fields.jsonb.JSONField(encoder=django.core.serializers.json.DjangoJSONEncoder),
        ),
        migrations.AlterField(
            model_name='medium',
            name='additional_context',
            field=django.contrib.postgres.fields.jsonb.JSONField(default=None, encoder=django.core.serializers.json.DjangoJSONEncoder, null=True),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='TestFKModel',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('value', models.CharField(max_length=64)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='TestFKModel2',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('value', models.CharField(max_length=64)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='TestModel',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('value', models.CharField(max_length=64)),
                ('fk', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='tests.TestFKModel')),
                ('fk2', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='tests.TestFKModel2')),
                ('fk_m2m', models.ManyToManyField(related_name='+', to='tests.TestFKModel')),
            ],
            options={
            },
            bases=(models.Model,),
        ),
    ]
